Instructions
============

Circuits are composed of instructions, placed on qubits. These instructions can
be of several types, detailed bellow.

The class
---------

.. automodule:: mpqp.core.instruction.instruction

Instruction types
-----------------

Instructions can be of type:

.. toctree::
   :maxdepth: 1

   gates
   measures
   barrier

Each of there are described on their respective page.